translate.convert.po2tiki

Package translate :: Package convert :: Module po2tiki |
[hide private]
[frames] | no frames]

# Module po2tiki

source code

Convert .po files to TikiWiki's language.php files.

Classes | [hide private]
| po2tiki

Functions | [hide private]
convertpo(inputfile, outputfile, template=None) Converts from po file format to tiki. | source code
main(argv=None) Will convert from .po to tiki style .php | source code

Imports: sys, tiki, po

Function Details | [hide private]

### convertpo(inputfile, outputfile, template=None) | source code
Converts from po file format to tiki. Parameters: `inputfile` - file handle of the source `outputfile` - file handle to write to `template` - unused